window.Gleam.initSearch([{"doc":"sqlight","title":"sqlight","content":"# sqlight\n\n[![Package Version](https://img.shields.io/hexpm/v/sqlight)](https://hex.pm/packages/sqlight)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/sqlight/)\n\nUse [SQLite](https://www.sqlite.org/index.html) from Gleam!\n\nThis library is a Gleam wrapper around the excellent Erlang library\n[esqlite](https://hex.pm/packages/esqlite), which in turn is a wrapper around\nthe SQLite C library. It is implemented as a NIF, which means that the SQLite\ndatabase engine is linked to the erlang virtual machine.\n\n```sh\ngleam add sqlight\n```\n```gleam\npub fn main() {\n  use conn &lt;- sqlight.with_connection(&quot;:memory:&quot;)\n  let cat_decoder = dynamic.tuple2(dynamic.string, dynamic.int)\n\n  let sql = &quot;\n  create table cats (name text, age int);\n\n  insert into cats (name, age) values \n  (&#39;Nubi&#39;, 4),\n  (&#39;Biffy&#39;, 10),\n  (&#39;Ginny&#39;, 6);\n  &quot;\n  assert Ok(Nil) = sqlight.exec(sql, conn)\n\n  let sql = &quot;\n  select name, age from cats\n  where age &lt; ?\n  &quot;\n  assert Ok([#(&quot;Nubi&quot;, 4), #(&quot;Ginny&quot;, 6)]) =\n    sqlight.query(sql, on: conn, with: [sqlight.int(7)], expecting: cat_decoder)\n}\n```\n\nDocumentation can be found at &lt;https://hexdocs.pm/sqlight&gt;.\n\n## Why SQLite?\n\nSQLite is a implementation of SQL as a library. This means that you don&#39;t run a\nseparate SQL server that your program communicates with, but you embed the SQL\nimplementation directly in your program. SQLite stores its data in a single\nfile. The file format is portable between different machine architectures. It\nsupports atomic transactions and it is possible to access the file by multiple\nprocesses and different programs.\n\nYou can also use in-memory databases with SQLite, which may be useful for testing.\n","url":"index.html"}]);